@@ -1,10 +1,9 @@
 from pkg_resources import get_distribution, DistributionNotFound
 
-# Wrapping Header
 __project__ = 'z2n-periodogram'
 __version__ = None
+__license__ = 'MIT'
 __author__ = 'Yohan Alexander'
-__license__ = 'MIT LICENSE'
 __copyright__ = 'Copyright (C) 2020, Z2n Software, by Yohan Alexander.'
 __description__ = 'A program for interative periodograms analysis.'
 __maintainer__ = 'Yohan Alexander'
@@ -29,6 +28,5 @@ except DistributionNotFound:
     VERSION = __project__ + '-' + '(local)'
 else:
     VERSION = __project__ + '-' + __version__
-    from z2n.main import cli
     from z2n.plot import Plot
     from z2n.series import Series
